/// <reference types="react" />
import './index.scss';
type ProcessType = 'shadow' | 'ellipsis';
interface TextProcessProps {
    text: string;
    type?: ProcessType;
    isDefaultFold?: boolean;
    isRenderShowAllDOM?: boolean;
    unfoldButtonText?: string | JSX.Element | JSX.Element[];
    foldButtonText?: string | JSX.Element | JSX.Element[];
    buttonBeforeSlot?: string | JSX.Element | JSX.Element[];
    buttonClassName?: string;
    buttonStyle?: React.CSSProperties;
    lineHeight?: number;
    ellipsisLineClamp?: number;
    className?: string;
    style?: React.CSSProperties;
    isShowAllContent?: boolean;
    isMustButton?: boolean;
    isMustNoButton?: boolean;
    shadowInitBoxShowH?: number;
    onClick?: () => void;
    getIsFold?: (v: boolean) => void;
    /**
     * 是否使用Js逻辑计算文字开始折叠时显示的文案，可以传字号大小
     * 注意：
     * 1、启用此功能是为了兼容部分浏览器不支持display: -webkit-box;属性的使用（或出现异常）
     * 2、计算出来的文案可能不够完美，可以通过extraOccupiedW调整计算的误差
     * 3、这时只支持传string类型内容
     * 4、按钮文案尽量传DOM结构
     * 5、仅ellipsis时有效
     */
    isJsComputed?: boolean;
    fontSize?: number;
    /**
     * 紧跟文字内容尾部的额外内容，可以是icon等任意内容，例如超链接icon，点击跳转到外部网站
     * 文案溢出时显示在...后面，不溢出时在文字尾部
     * 注意：
     * 1、启用isJsComputed时，textEndSlot所占的宽需要通过extraOccupiedW告知才能精确计算
     * 2、仅ellipsis时有效
     */
    textEndSlot?: any;
    extraOccupiedW?: number;
}
declare function TextOverflowProcessor(props: TextProcessProps): JSX.Element;
declare namespace TextOverflowProcessor {
    var defaultProps: {
        text: string;
        type: string;
        isDefaultFold: boolean;
        isRenderShowAllDOM: boolean;
        unfoldButtonText: string;
        foldButtonText: string;
        buttonBeforeSlot: null;
        buttonClassName: string;
        buttonStyle: {};
        lineHeight: number;
        ellipsisLineClamp: number;
        className: string;
        style: {};
        isShowAllContent: boolean;
        isMustButton: boolean;
        isMustNoButton: boolean;
        shadowInitBoxShowH: number;
        onClick: null;
        getIsFold: null;
        isJsComputed: boolean;
        fontSize: number;
        textEndSlot: null;
        extraOccupiedW: number;
    };
}
declare const _default: import("react").MemoExoticComponent<typeof TextOverflowProcessor>;
export default _default;
